import crypto from "crypto";
import { Session } from "../models/session";
import { Response } from "express";

export const DEFAULT_SESSION_EXPIRATION = 7 * 24 * 60 * 60 * 1000; // 7 days
export const ADMIN_MAX_USERS_PER_PAGE = 10;

export async function saveSession(res: Response, accountName: string) {
  try {
    // Generate a random session ID
    const sessionId = crypto.randomBytes(32).toString("hex");

    // Create a new session document
    const session = new Session({
      sessionId: sessionId,
      accountName: accountName, // Assuming you have the user information in req.user
    });

    // Save the session to MongoDB
    await session.save();

    // Respond with the session ID
    res.status(200).json({ sessionId });
  } catch (error) {
    console.error("Error saving session:", error);
    res.status(500).json({ status: "err" });
  }
}
